@@ -20,10 +20,11 @@ class aib_logger:
         WARNING="WARNING"
         ERROR="ERROR"
 
-    def __init__(self, project:str, logger_name:str="aib_custom_logger"):
+    def __init__(self, project:str, pipeline_name:str="", logger_name:str="aib_custom_logger"):
         import logging
         import google.cloud.logging
         self.project=project
+        self.pipeline_name=pipeline_name
         client = google.cloud.logging.Client(project=project)
         self.logger = client.logger(name=logger_name)
 
@@ -38,7 +39,7 @@ class aib_logger:
            ):
         import inspect
         payload={
-            "pipeline_run_name":"{{$.pipeline_job_name}}",
+            "pipeline_run_name":self.pipeline_name,
             "component_name": inspect.stack()[1].function,
             "project":self.project,
             "category":category.value,
